@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: ISO-8859-1 -*-
 import sys
+import setup_test
 import libxml2
 
 # Memory debug specific
@@ -110,4 +111,3 @@ if libxml2.debugMemory(1) == 0:
     print("OK")
 else:
     print("Memory leak %d bytes" % (libxml2.debugMemory(1)))
-    libxml2.dumpMemory()
