@@ -7,7 +7,7 @@
  *
  * See Copyright for the status of this software.
  *
- * daniel@veillard.com
+ * Author: Daniel Veillard
  */
 
 #include "libxml.h"
@@ -39,7 +39,7 @@ static int tests_quiet = 0;
 #define MAX_TIME 2 /* seconds */
 
 static clock_t t0;
-int timeout = 0;
+static int timeout = 0;
 
 static void reset_timout(void) {
     timeout = 0;
@@ -89,12 +89,10 @@ static unsigned int currentTest = 0;
 static int instate = 0;
 
 /**
- * hugeMatch:
- * @URI: an URI to test
- *
  * Check for an huge: query
  *
- * Returns 1 if yes and 0 if another Input module should be used
+ * @param URI  an URI to test
+ * @returns 1 if yes and 0 if another Input module should be used
  */
 static int
 hugeMatch(const char * URI) {
@@ -104,13 +102,11 @@ hugeMatch(const char * URI) {
 }
 
 /**
- * hugeOpen:
- * @URI: an URI to test
- *
- * Return a pointer to the huge: query handler, in this example simply
+ * Returns a pointer to the huge: query handler, in this example simply
  * the current pointer...
  *
- * Returns an Input context or NULL in case or error
+ * @param URI  an URI to test
+ * @returns an Input context or NULL in case or error
  */
 static void *
 hugeOpen(const char * URI) {
@@ -132,12 +128,10 @@ found:
 }
 
 /**
- * hugeClose:
- * @context: the read context
- *
  * Close the huge: query handler
  *
- * Returns 0 or -1 in case of error
+ * @param context  the read context
+ * @returns 0 or -1 in case of error
  */
 static int
 hugeClose(void * context) {
@@ -148,7 +142,7 @@ hugeClose(void * context) {
 
 #define CHUNK 4096
 
-char filling[CHUNK + 1];
+static char filling[CHUNK + 1];
 
 static void fillFilling(void) {
     int i;
@@ -159,19 +153,17 @@ static void fillFilling(void) {
     filling[CHUNK] = 0;
 }
 
-size_t maxlen = 64 * 1024 * 1024;
-size_t curlen = 0;
-size_t dotlen;
+static size_t maxlen = 64 * 1024 * 1024;
+static size_t curlen = 0;
+static size_t dotlen;
 
 /**
- * hugeRead:
- * @context: the read context
- * @buffer: where to store data
- * @len: number of bytes to read
- *
  * Implement an huge: query read.
  *
- * Returns the number of bytes read or -1 in case of error
+ * @param context  the read context
+ * @param buffer  where to store data
+ * @param len  number of bytes to read
+ * @returns the number of bytes read or -1 in case of error
  */
 static int
 hugeRead(void *context, char *buffer, int len)
@@ -229,9 +221,9 @@ hugeRead(void *context, char *buffer, int len)
  *									*
  ************************************************************************/
 
-unsigned int crazy_indx = 0;
+static unsigned int crazy_indx = 0;
 
-const char *crazy = "<?xml version='1.0' encoding='UTF-8'?>\
+static const char *const crazy = "<?xml version='1.0' encoding='UTF-8'?>\
 <?tst ?>\
 <!-- tst -->\
 <!DOCTYPE foo [\
@@ -252,12 +244,10 @@ foo\
 <!-- tst -->";
 
 /**
- * crazyMatch:
- * @URI: an URI to test
- *
  * Check for a crazy: query
  *
- * Returns 1 if yes and 0 if another Input module should be used
+ * @param URI  an URI to test
+ * @returns 1 if yes and 0 if another Input module should be used
  */
 static int
 crazyMatch(const char * URI) {
@@ -267,13 +257,11 @@ crazyMatch(const char * URI) {
 }
 
 /**
- * crazyOpen:
- * @URI: an URI to test
- *
- * Return a pointer to the crazy: query handler, in this example simply
+ * Returns a pointer to the crazy: query handler, in this example simply
  * the current pointer...
  *
- * Returns an Input context or NULL in case or error
+ * @param URI  an URI to test
+ * @returns an Input context or NULL in case or error
  */
 static void *
 crazyOpen(const char * URI) {
@@ -290,12 +278,10 @@ crazyOpen(const char * URI) {
 }
 
 /**
- * crazyClose:
- * @context: the read context
- *
  * Close the crazy: query handler
  *
- * Returns 0 or -1 in case of error
+ * @param context  the read context
+ * @returns 0 or -1 in case of error
  */
 static int
 crazyClose(void * context) {
@@ -305,14 +291,12 @@ crazyClose(void * context) {
 
 
 /**
- * crazyRead:
- * @context: the read context
- * @buffer: where to store data
- * @len: number of bytes to read
- *
  * Implement an crazy: query read.
  *
- * Returns the number of bytes read or -1 in case of error
+ * @param context  the read context
+ * @param buffer  where to store data
+ * @param len  number of bytes to read
+ * @returns the number of bytes read or -1 in case of error
  */
 static int
 crazyRead(void *context, char *buffer, int len)
@@ -402,15 +386,13 @@ initializeLibxml2(void) {
  *									*
  ************************************************************************/
 
-unsigned long callbacks = 0;
+static unsigned long callbacks = 0;
 
 /**
- * isStandaloneCallback:
- * @ctxt:  An XML parser context
- *
  * Is this document tagged standalone ?
  *
- * Returns 1 if true
+ * @param ctxt  An XML parser context
+ * @returns 1 if true
  */
 static int
 isStandaloneCallback(void *ctx ATTRIBUTE_UNUSED)
@@ -420,12 +402,10 @@ isStandaloneCallback(void *ctx ATTRIBUTE_UNUSED)
 }
 
 /**
- * hasInternalSubsetCallback:
- * @ctxt:  An XML parser context
- *
  * Does this document has an internal subset
  *
- * Returns 1 if true
+ * @param ctxt  An XML parser context
+ * @returns 1 if true
  */
 static int
 hasInternalSubsetCallback(void *ctx ATTRIBUTE_UNUSED)
@@ -435,12 +415,10 @@ hasInternalSubsetCallback(void *ctx ATTRIBUTE_UNUSED)
 }
 
 /**
- * hasExternalSubsetCallback:
- * @ctxt:  An XML parser context
- *
  * Does this document has an external subset
  *
- * Returns 1 if true
+ * @param ctxt  An XML parser context
+ * @returns 1 if true
  */
 static int
 hasExternalSubsetCallback(void *ctx ATTRIBUTE_UNUSED)
@@ -450,10 +428,9 @@ hasExternalSubsetCallback(void *ctx ATTRIBUTE_UNUSED)
 }
 
 /**
- * internalSubsetCallback:
- * @ctxt:  An XML parser context
- *
  * Does this document has an internal subset
+ *
+ * @param ctxt  An XML parser context
  */
 static void
 internalSubsetCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -465,10 +442,9 @@ internalSubsetCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * externalSubsetCallback:
- * @ctxt:  An XML parser context
- *
  * Does this document has an external subset
+ *
+ * @param ctxt  An XML parser context
  */
 static void
 externalSubsetCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -480,18 +456,16 @@ externalSubsetCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * resolveEntityCallback:
- * @ctxt:  An XML parser context
- * @publicId: The public ID of the entity
- * @systemId: The system ID of the entity
- *
  * Special entity resolver, better left to the parser, it has
  * more context than the application layer.
  * The default behaviour is to NOT resolve the entities, in that case
  * the ENTITY_REF nodes are built in the structure (and the parameter
  * values).
  *
- * Returns the xmlParserInputPtr if inlined or NULL for DOM behaviour.
+ * @param ctxt  An XML parser context
+ * @param publicId  The public ID of the entity
+ * @param systemId  The system ID of the entity
+ * @returns the xmlParserInput if inlined or NULL for DOM behaviour.
  */
 static xmlParserInputPtr
 resolveEntityCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -503,13 +477,11 @@ resolveEntityCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * getEntityCallback:
- * @ctxt:  An XML parser context
- * @name: The entity name
- *
  * Get an entity by name
  *
- * Returns the xmlParserInputPtr if inlined or NULL for DOM behaviour.
+ * @param ctxt  An XML parser context
+ * @param name  The entity name
+ * @returns the xmlParserInput if inlined or NULL for DOM behaviour.
  */
 static xmlEntityPtr
 getEntityCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -520,13 +492,11 @@ getEntityCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * getParameterEntityCallback:
- * @ctxt:  An XML parser context
- * @name: The entity name
- *
  * Get a parameter entity by name
  *
- * Returns the xmlParserInputPtr
+ * @param ctxt  An XML parser context
+ * @param name  The entity name
+ * @returns the xmlParserInput
  */
 static xmlEntityPtr
 getParameterEntityCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -538,15 +508,14 @@ getParameterEntityCallback(void *ctx ATTRIBUTE_UNUSED,
 
 
 /**
- * entityDeclCallback:
- * @ctxt:  An XML parser context
- * @name:  the entity name
- * @type:  the entity type
- * @publicId: The public ID of the entity
- * @systemId: The system ID of the entity
- * @content: the entity value (without processing).
- *
  * An entity definition has been parsed
+ *
+ * @param ctxt  An XML parser context
+ * @param name  the entity name
+ * @param type  the entity type
+ * @param publicId  The public ID of the entity
+ * @param systemId  The system ID of the entity
+ * @param content  the entity value (without processing).
  */
 static void
 entityDeclCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -560,12 +529,11 @@ entityDeclCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * attributeDeclCallback:
- * @ctxt:  An XML parser context
- * @name:  the attribute name
- * @type:  the attribute type
- *
  * An attribute definition has been parsed
+ *
+ * @param ctxt  An XML parser context
+ * @param name  the attribute name
+ * @param type  the attribute type
  */
 static void
 attributeDeclCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -579,13 +547,12 @@ attributeDeclCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * elementDeclCallback:
- * @ctxt:  An XML parser context
- * @name:  the element name
- * @type:  the element type
- * @content: the element value (without processing).
- *
  * An element definition has been parsed
+ *
+ * @param ctxt  An XML parser context
+ * @param name  the element name
+ * @param type  the element type
+ * @param content  the element value (without processing).
  */
 static void
 elementDeclCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -597,13 +564,12 @@ elementDeclCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * notationDeclCallback:
- * @ctxt:  An XML parser context
- * @name: The name of the notation
- * @publicId: The public ID of the entity
- * @systemId: The system ID of the entity
- *
  * What to do when a notation declaration has been parsed.
+ *
+ * @param ctxt  An XML parser context
+ * @param name  The name of the notation
+ * @param publicId  The public ID of the entity
+ * @param systemId  The system ID of the entity
  */
 static void
 notationDeclCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -615,14 +581,13 @@ notationDeclCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * unparsedEntityDeclCallback:
- * @ctxt:  An XML parser context
- * @name: The name of the entity
- * @publicId: The public ID of the entity
- * @systemId: The system ID of the entity
- * @notationName: the name of the notation
- *
  * What to do when an unparsed entity declaration is parsed
+ *
+ * @param ctxt  An XML parser context
+ * @param name  The name of the entity
+ * @param publicId  The public ID of the entity
+ * @param systemId  The system ID of the entity
+ * @param notationName  the name of the notation
  */
 static void
 unparsedEntityDeclCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -635,12 +600,11 @@ unparsedEntityDeclCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * setDocumentLocatorCallback:
- * @ctxt:  An XML parser context
- * @loc: A SAX Locator
- *
  * Receive the document locator at startup, actually xmlDefaultSAXLocator
  * Everything is available on the context, so this is useless in our case.
+ *
+ * @param ctxt  An XML parser context
+ * @param loc  A SAX Locator
  */
 static void
 setDocumentLocatorCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -650,10 +614,9 @@ setDocumentLocatorCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * startDocumentCallback:
- * @ctxt:  An XML parser context
- *
  * called when the document start being processed.
+ *
+ * @param ctxt  An XML parser context
  */
 static void
 startDocumentCallback(void *ctx ATTRIBUTE_UNUSED)
@@ -662,10 +625,9 @@ startDocumentCallback(void *ctx ATTRIBUTE_UNUSED)
 }
 
 /**
- * endDocumentCallback:
- * @ctxt:  An XML parser context
- *
  * called when the document end has been detected.
+ *
+ * @param ctxt  An XML parser context
  */
 static void
 endDocumentCallback(void *ctx ATTRIBUTE_UNUSED)
@@ -675,11 +637,10 @@ endDocumentCallback(void *ctx ATTRIBUTE_UNUSED)
 
 #if 0
 /**
- * startElementCallback:
- * @ctxt:  An XML parser context
- * @name:  The element name
- *
  * called when an opening tag has been processed.
+ *
+ * @param ctxt  An XML parser context
+ * @param name  The element name
  */
 static void
 startElementCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -691,11 +652,10 @@ startElementCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * endElementCallback:
- * @ctxt:  An XML parser context
- * @name:  The element name
- *
  * called when the end of an element has been detected.
+ *
+ * @param ctxt  An XML parser context
+ * @param name  The element name
  */
 static void
 endElementCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -707,13 +667,12 @@ endElementCallback(void *ctx ATTRIBUTE_UNUSED,
 #endif
 
 /**
- * charactersCallback:
- * @ctxt:  An XML parser context
- * @ch:  a xmlChar string
- * @len: the number of xmlChar
- *
  * receiving some chars from the parser.
  * Question: how much at a time ???
+ *
+ * @param ctxt  An XML parser context
+ * @param ch  a xmlChar string
+ * @param len  the number of xmlChar
  */
 static void
 charactersCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -724,11 +683,10 @@ charactersCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * referenceCallback:
- * @ctxt:  An XML parser context
- * @name:  The entity name
- *
  * called when an entity reference is detected.
+ *
+ * @param ctxt  An XML parser context
+ * @param name  The entity name
  */
 static void
 referenceCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -738,14 +696,13 @@ referenceCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * ignorableWhitespaceCallback:
- * @ctxt:  An XML parser context
- * @ch:  a xmlChar string
- * @start: the first char in the string
- * @len: the number of xmlChar
- *
  * receiving some ignorable whitespaces from the parser.
  * Question: how much at a time ???
+ *
+ * @param ctxt  An XML parser context
+ * @param ch  a xmlChar string
+ * @param start  the first char in the string
+ * @param len  the number of xmlChar
  */
 static void
 ignorableWhitespaceCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -756,13 +713,12 @@ ignorableWhitespaceCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * processingInstructionCallback:
- * @ctxt:  An XML parser context
- * @target:  the target name
- * @data: the PI data's
- * @len: the number of xmlChar
- *
  * A processing instruction has been parsed.
+ *
+ * @param ctxt  An XML parser context
+ * @param target  the target name
+ * @param data  the PI data's
+ * @param len  the number of xmlChar
  */
 static void
 processingInstructionCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -773,12 +729,11 @@ processingInstructionCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * cdataBlockCallback:
- * @ctx: the user data (XML parser context)
- * @value:  The pcdata content
- * @len:  the block length
- *
  * called when a pcdata block has been parsed
+ *
+ * @param ctx  the user data (XML parser context)
+ * @param value  The pcdata content
+ * @param len  the block length
  */
 static void
 cdataBlockCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -789,11 +744,10 @@ cdataBlockCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * commentCallback:
- * @ctxt:  An XML parser context
- * @value:  the comment content
- *
  * A comment has been parsed.
+ *
+ * @param ctxt  An XML parser context
+ * @param value  the comment content
  */
 static void
 commentCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -803,13 +757,12 @@ commentCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * warningCallback:
- * @ctxt:  An XML parser context
- * @msg:  the message to display/transmit
- * @...:  extra parameters for the message display
- *
  * Display and format a warning messages, gives file, line, position and
  * extra parameters.
+ *
+ * @param ctxt  An XML parser context
+ * @param msg  the message to display/transmit
+ * @param ...  extra parameters for the message display
  */
 static void
 warningCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -819,13 +772,12 @@ warningCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * errorCallback:
- * @ctxt:  An XML parser context
- * @msg:  the message to display/transmit
- * @...:  extra parameters for the message display
- *
  * Display and format a error messages, gives file, line, position and
  * extra parameters.
+ *
+ * @param ctxt  An XML parser context
+ * @param msg  the message to display/transmit
+ * @param ...  extra parameters for the message display
  */
 static void
 errorCallback(void *ctx ATTRIBUTE_UNUSED, const char *msg ATTRIBUTE_UNUSED,
@@ -835,13 +787,12 @@ errorCallback(void *ctx ATTRIBUTE_UNUSED, const char *msg ATTRIBUTE_UNUSED,
 }
 
 /**
- * fatalErrorCallback:
- * @ctxt:  An XML parser context
- * @msg:  the message to display/transmit
- * @...:  extra parameters for the message display
- *
  * Display and format a fatalError messages, gives file, line, position and
  * extra parameters.
+ *
+ * @param ctxt  An XML parser context
+ * @param msg  the message to display/transmit
+ * @param ...  extra parameters for the message display
  */
 static void
 fatalErrorCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -855,11 +806,10 @@ fatalErrorCallback(void *ctx ATTRIBUTE_UNUSED,
  */
 
 /**
- * startElementNsCallback:
- * @ctxt:  An XML parser context
- * @name:  The element name
- *
  * called when an opening tag has been processed.
+ *
+ * @param ctxt  An XML parser context
+ * @param name  The element name
  */
 static void
 startElementNsCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -876,11 +826,10 @@ startElementNsCallback(void *ctx ATTRIBUTE_UNUSED,
 }
 
 /**
- * endElementCallback:
- * @ctxt:  An XML parser context
- * @name:  The element name
- *
  * called when the end of an element has been detected.
+ *
+ * @param ctxt  An XML parser context
+ * @param name  The element name
  */
 static void
 endElementNsCallback(void *ctx ATTRIBUTE_UNUSED,
@@ -935,15 +884,13 @@ static xmlSAXHandlerPtr callbackSAX2Handler = &callbackSAX2HandlerStruct;
  ************************************************************************/
 
 /**
- * readerTest:
- * @filename: the file to parse
- * @max_size: size of the limit to test
- * @options: parsing options
- * @fail: should a failure be reported
- *
  * Parse a memory generated file using SAX
  *
- * Returns 0 in case of success, an error code otherwise
+ * @param filename  the file to parse
+ * @param max_size  size of the limit to test
+ * @param options  parsing options
+ * @param fail  should a failure be reported
+ * @returns 0 in case of success, an error code otherwise
  */
 static int
 saxTest(const char *filename, size_t limit, int options, int fail) {
@@ -987,15 +934,13 @@ saxTest(const char *filename, size_t limit, int options, int fail) {
 }
 #ifdef LIBXML_READER_ENABLED
 /**
- * readerTest:
- * @filename: the file to parse
- * @max_size: size of the limit to test
- * @options: parsing options
- * @fail: should a failure be reported
- *
  * Parse a memory generated file using the xmlReader
  *
- * Returns 0 in case of success, an error code otherwise
+ * @param filename  the file to parse
+ * @param max_size  size of the limit to test
+ * @param options  parsing options
+ * @param fail  should a failure be reported
+ * @returns 0 in case of success, an error code otherwise
  */
 static int
 readerTest(const char *filename, size_t limit, int options, int fail) {
