@@ -4,7 +4,7 @@
  *
  * See Copyright for the status of this software.
  *
- * daniel@veillard.com
+ * Author: Daniel Veillard
  */
 
 
@@ -19,9 +19,7 @@
 #include <libxml/xmlmemory.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
-#include <libxml/valid.h>
 #include <libxml/xlink.h>
-#include <libxml/globals.h>
 
 #define XLINK_NAMESPACE (BAD_CAST "http://www.w3.org/1999/xlink/namespace/")
 #define XHTML_NAMESPACE (BAD_CAST "http://www.w3.org/1999/xhtml/")
@@ -36,35 +34,36 @@ static xlinkHandlerPtr xlinkDefaultHandler = NULL;
 static xlinkNodeDetectFunc	xlinkDefaultDetect = NULL;
 
 /**
- * xlinkGetDefaultHandler:
- *
  * Get the default xlink handler.
  *
- * Returns the current xlinkHandlerPtr value.
+ * @deprecated Don't use.
+ *
+ * @returns the current xlinkHandler value.
  */
-xlinkHandlerPtr
+xlinkHandler *
 xlinkGetDefaultHandler(void) {
     return(xlinkDefaultHandler);
 }
 
 
 /**
- * xlinkSetDefaultHandler:
- * @handler:  the new value for the xlink handler block
- *
  * Set the default xlink handlers
+ *
+ * @deprecated Don't use.
+ *
+ * @param handler  the new value for the xlink handler block
  */
 void
-xlinkSetDefaultHandler(xlinkHandlerPtr handler) {
+xlinkSetDefaultHandler(xlinkHandler *handler) {
     xlinkDefaultHandler = handler;
 }
 
 /**
- * xlinkGetDefaultDetect:
- *
  * Get the default xlink detection routine
  *
- * Returns the current function or NULL;
+ * @deprecated Don't use.
+ *
+ * @returns the current function or NULL;
  */
 xlinkNodeDetectFunc
 xlinkGetDefaultDetect	(void) {
@@ -72,10 +71,11 @@ xlinkGetDefaultDetect	(void) {
 }
 
 /**
- * xlinkSetDefaultDetect:
- * @func: pointer to the new detection routine.
- *
  * Set the default xlink detection routine
+ *
+ * @deprecated Don't use.
+ *
+ * @param func  pointer to the new detection routine.
  */
 void
 xlinkSetDefaultDetect	(xlinkNodeDetectFunc func) {
@@ -90,21 +90,21 @@ xlinkSetDefaultDetect	(xlinkNodeDetectFunc func) {
 
 
 /**
- * xlinkIsLink:
- * @doc:  the document containing the node
- * @node:  the node pointer itself
- *
  * Check whether the given node carries the attributes needed
  * to be a link element (or is one of the linking elements issued
  * from the (X)HTML DtDs).
  * This routine don't try to do full checking of the link validity
  * but tries to detect and return the appropriate link type.
  *
- * Returns the xlinkType of the node (XLINK_TYPE_NONE if there is no
+ * @deprecated The XLink code was never finished.
+ *
+ * @param doc  the document containing the node
+ * @param node  the node pointer itself
+ * @returns the xlinkType of the node (XLINK_TYPE_NONE if there is no
  *         link detected.
  */
 xlinkType
-xlinkIsLink	(xmlDocPtr doc, xmlNodePtr node) {
+xlinkIsLink	(xmlDoc *doc, xmlNode *node) {
     xmlChar *type = NULL, *role = NULL;
     xlinkType ret = XLINK_TYPE_NONE;
 
